import 'package:flutter/services.dart';
import 'package:yaml/yaml.dart';

import '../../flutter_translaty.dart';

class TranslatyLocalConfig {
  final String clientKey;
  final String projectId;
  final String teamId;
  final String? translatyUrl;

  TranslatyLocalConfig({
    required this.clientKey,
    required this.projectId,
    required this.teamId,
    this.translatyUrl,
  });
}

class LocalConfigReader {
  Future<String?> _getTranslatyYaml() async {
    try {
      return await rootBundle.loadString("translaty.yaml");
    } catch (ex) {
      EasyLocalization.logger
          .warning("Could not find translaty.yaml. Message: $ex");
      return null;
    }
  }

  Future<TranslatyLocalConfig?> readConfig() async {
    final translatyYaml = await _getTranslatyYaml();
    if (translatyYaml == null) return null;
    final yaml = loadYaml(translatyYaml);
    final translatyConfig = yaml["translaty"];
    if (translatyConfig == null) {
      EasyLocalization.logger.error(
        "Did not find the entrypoint translaty in the translaty.yaml file. Aborting",
      );
      return null;
    }
    final teamId = translatyConfig["team_id"];
    final projectId = translatyConfig["project_id"];
    final clientKey = translatyConfig["client_key"];
    if (clientKey == null) {
      EasyLocalization.logger.error(
        "Yyour translaty.yaml does not contain a client_key. Aborting",
      );
      return null;
    }
    final String? translatyUrl = translatyConfig["translaty_url"];
    return TranslatyLocalConfig(
      clientKey: clientKey,
      projectId: projectId,
      teamId: teamId,
      translatyUrl: translatyUrl,
    );
  }
}
