import 'package:flutter/material.dart';
import 'package:flutter_translaty/src/translations.dart';
import 'package:flutter_translaty/src/translaty/config_reader.dart';
import 'package:translaty_fetcher/translaty_fetcher.dart';

import '../../flutter_translaty.dart';

class OtaService {
  final LocalConfigReader _configReader;
  final _fetcher = TranslatyFetcher();

  OtaService(this._configReader);

  TranslatyLocalConfig? _localConfig;
  TranslatyConfig? _remoteConfig;

  bool get shallExecuteOta => _remoteConfig?.otaEnabled == true;

  Future<void> init() async {
    _localConfig = await _configReader.readConfig();
    final config = _localConfig;
    if (config == null) {
      EasyLocalization.logger.error(
          "Could not read the translaty config. No Over-The-Air update can be done");
      return;
    }

    _remoteConfig = await _fetcher.getConfig(
      translatyClientKey: config.clientKey,
      translatyUrl: config.translatyUrl,
    );
  }

  Future<Map<String, dynamic>?> getData(
    Locale l,
    Translations before,
  ) async {
    final config = _localConfig;
    if (config == null) {
      EasyLocalization.logger.warning(
          "Not making over the air update because there is no config.");
      return null;
    }

    final newData = await _fetcher.getOneLanguage(
      translatyClientKey: config.clientKey,
      language: l.toString(),
      translatyUrl: config.translatyUrl,
    );
    for (final item in before.translations!.entries) {
      if (!newData.containsKey(item.key)) {
        newData[item.key] = item.value;
      }
    }
    return newData;
  }
}
